/// <reference types="node" />
import { EventEmitter } from 'events';
import * as execa from 'execa';
import { AdapterInstance } from './adapter';
/**
 * Utility for creating ISO 9660 images.
 *
 * @class Mkiso
 */
declare class Mkiso extends EventEmitter {
    protected readonly defaultAdapters: {
        [os: string]: string;
    };
    private readonly _platform;
    private _adapter;
    private _source;
    private _output;
    private _label;
    private _publisher;
    private _verbose;
    /**
     * Creates an instance of Mkiso.
     *
     * @param {string} sourceDir
     * @memberof Mkiso
     */
    constructor(sourceDir: string);
    /**
     * Set the volume name.
     *
     * @param {string} name
     * @returns
     * @memberof Mkiso
     */
    label(name: string): this;
    /**
     * Set the publisher name.
     *
     * @param {string} name
     * @returns
     * @memberof Mkiso
     */
    publisher(name: string): this;
    /**
     * Enable the verbose mode.
     *
     * @returns
     * @memberof Mkiso
     */
    verbose(): this;
    /**
     * Set the iso output file path.
     *
     * @param {string} target
     * @returns
     * @memberof Mkiso
     */
    output(target: string): this;
    /**
     * Override the default adapter with a custom one.
     * You can use an MkisoAdapter adapter instance
     * or the name of an adapter into the adapters folder or link an external one.
     *
     * @param {(string | Adapter)} adapter
     * @memberof Mkiso
     */
    adapter(adapter: string | AdapterInstance): Promise<this>;
    /**
     * Starts the burning process.
     *
     * @param {ReadonlyArray<string>} [args=[]]
     * @returns
     * @memberof Mkiso
     */
    exec(args?: ReadonlyArray<string>, options?: execa.Options): Promise<execa.ExecaReturns>;
    /**
     * Load the configured adapter.
     *
     * @private
     * @returns
     * @memberof Mkiso
     */
    private loadAdapter;
    /**
     * Set the default adapter based on OS platform.
     *
     * @private
     * @memberof Mkiso
     */
    private defaultAdapter;
    /**
     * Promisify access function.
     *
     * @private
     * @param {string} sourcePath
     * @returns
     * @memberof Mkiso
     */
    private pathExists;
}
export default function mkiso(sourceDir: string): Mkiso;
export {};
